@@ -114,7 +114,7 @@ def push_alert(title='{hostname}', success_msg='Process complete!',
     if '{hostname}' in title:
         fmt['hostname'] = HOSTNAME
 
-    if '{username}' in header:
+    if '{username}' in title:
         fmt['username'] = USERNAME
 
     title = title.format(**fmt)
